<?php
// Own namespace
namespace CoreFramework\Resolver\Command;

// Import framework stuff
use CoreFramework\Command\InvalidCommandException;
use CoreFramework\Generic\EmptyVariableException;
use CoreFramework\Manager\ManageableApplication;
use CoreFramework\Resolver\Command\CommandResolver;

/**
 * A command resolver for local (non-hubbed) HTML commands
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class HtmlCommandResolver extends BaseCommandResolver implements CommandResolver {
	/**
	 * Last successfull resolved command
	 */
	private $lastCommandInstance = NULL;

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set prefix to "html"
		$this->setClassPrefix('html');
	}

	/**
	 * Creates an instance of a Html command resolver with a given default command
	 *
	 * @param	$commandName				The default command we shall execute
	 * @param	$applicationInstance		An instance of a manageable application helper class
	 * @return	$resolverInstance			The prepared command resolver instance
	 * @throws	EmptyVariableException		Thrown if default command is not set
	 * @throws	InvalidCommandException		Thrown if default command is invalid
	 */
	public static final function createHtmlCommandResolver ($commandName, ManageableApplication $applicationInstance) {
		// Create the new instance
		$resolverInstance = new HtmlCommandResolver();

		// Is the variable $commandName set and the command is valid?
		if (empty($commandName)) {
			// Then thrown an exception here
			throw new EmptyVariableException(array($resolverInstance, 'commandName'), self::EXCEPTION_UNEXPECTED_EMPTY_STRING);
		} elseif ($resolverInstance->isCommandValid($commandName) === false) {
			// Invalid command found
			throw new InvalidCommandException(array($resolverInstance, $commandName), self::EXCEPTION_INVALID_COMMAND);
		}

		// Set the application instance
		$resolverInstance->setApplicationInstance($applicationInstance);

		// Return the prepared instance
		return $resolverInstance;
	}

}
